#include <score.h>
#include <score.moc>

#include <qpixmap.h>
#include <qstring.h>
#include <qdstream.h>

#include "bitfont.h"

Score::Score(QWidget *parent, const char *name, Bitfont *font) : QWidget(parent, name)
{
    bitfont = font;

    QString libDir;
    libDir.setStr(KApplication::kde_datadir());
    libDir.append("/kpacman/");
    file.setName((const char *) (libDir+"highScore"));
    read();

    for (int p = 0; p < maxPlayer; p++)
	PlayerScore[p] = 0;

    repaint();
}

Score::~Score()
{
    write();
}

void Score::paintEvent( QPaintEvent *e)
{

    if (rect(3, 0, "1UP").intersects(e->rect())) {
	QPixmap pix = bitfont->text(i18n("1UP"), WHITE, BLACK);
        bitBlt(this, x(3), y(0), &pix);
    }

    if (rect(9, 0, "HIGH SCORE").intersects(e->rect())) {
	QPixmap pix = bitfont->text(i18n("HIGH SCORE"), WHITE, BLACK);
        bitBlt(this, x(9), y(0), &pix);
    }

    QString s;

    s.sprintf("%6d0", PlayerScore[0]/10);
    if (rect(0, 1, s).intersects(e->rect())) {
	QPixmap pix = bitfont->text(s, WHITE, BLACK);
	bitBlt(this, x(0), y(1), &pix);
   }

    s.sprintf("%8d0", HighScore/10);
    if (rect(8, 1, s).intersects(e->rect())) {
	QPixmap pix = bitfont->text(s, WHITE, BLACK);
	bitBlt(this, x(8), y(1), &pix);
   }
}

void Score::set(int score)
{
    set(score, 0);
}

void Score::set(int score, int player)
{
    if (player < 0 || player >= maxPlayer)
	return;
    else
	PlayerScore[player] = score;

    QString s;

    s.sprintf("%6d0", PlayerScore[player]/10);
    repaint(rect(0, 1, s), FALSE);

    if (score > HighScore) {
	HighScore = score;
	s.sprintf("%8d0", HighScore/10);
	repaint(rect(8, 1, s), FALSE);
    }
}

void Score::setFont(Bitfont *font)
{
    bitfont = font;
}

void Score::read()
{
    if (file.exists()) {
	if (file.open(IO_ReadOnly)) {
	    QDataStream s(&file);
	    s >> HighScore;
	    file.close();
	}
    } else {
	HighScore = 5000;
	write();
    }
}

void Score::write()
{
    if (file.open(IO_WriteOnly)) {
	QDataStream s(&file);
	s << HighScore;
	file.close();
    }
}

QRect Score::rect(int col, int row, QString str)
{
    QRect r = bitfont->rect(str);
    r.moveBy(x(col), y(row));
    return r;
}

int Score::x(int col)
{
    return col*bitfont->width();
}

int Score::y(int row)
{
    return row*(bitfont->height()+bitfont->height()/4);
}

